@@ -33,6 +33,7 @@
 #include <fcntl.h>
 #include <ctype.h>
 
+#include "util/sss_krb5.h"
 #include <krb5/locate_plugin.h>
 
 #include "providers/krb5/krb5_common.h"
@@ -381,6 +382,7 @@ krb5_error_code sssd_krb5_locator_lookup(void *private_data,
         ret = cbfunc(cbdata, socktype, ai->ai_addr);
         if (ret != 0) {
             PLUGIN_DEBUG(("cbfunc failed\n"));
+            freeaddrinfo(ai);
             return ret;
         } else {
             PLUGIN_DEBUG(("[%s] used\n", addr));
@@ -388,6 +390,7 @@ krb5_error_code sssd_krb5_locator_lookup(void *private_data,
     } else {
         PLUGIN_DEBUG(("[%s] NOT used\n", addr));
     }
+    freeaddrinfo(ai);
 
     return 0;
 }
