@@ -1476,10 +1476,13 @@ void fo_reset_services(struct fo_ctx *fo_ctx)
     }
 }
 
-struct fo_service *
-fo_get_server_service(struct fo_server *server)
+bool fo_svc_has_server(struct fo_service *service, struct fo_server *server)
 {
-    if (!server) return NULL;
-    return server->service;
-}
+    struct fo_server *srv;
 
+    DLIST_FOR_EACH(srv, service->server_list) {
+        if (srv == server) return true;
+    }
+
+    return false;
+}
