@@ -744,7 +744,8 @@ sdap_modify_shadow_lastchange_send(TALLOC_CTX *mem_ctx,
         ret = ENOMEM;
         goto done;
     }
-    values[0] = talloc_asprintf(values, "%ld", (long)time(NULL));
+    /* The attribute contains number of days since the epoch */
+    values[0] = talloc_asprintf(values, "%ld", (long)time(NULL)/86400);
     if (values[0] == NULL) {
         ret = ENOMEM;
         goto done;
