@@ -947,7 +947,8 @@ static void sdap_kinit_done(struct tevent_req *subreq)
          * retry with another KDC */
         DEBUG(SSSDBG_MINOR_FAILURE,
               ("Communication with KDC timed out, trying the next one\n"));
-        be_fo_set_port_status(state->be, state->kdc_srv, PORT_NOT_WORKING);
+        be_fo_set_port_status(state->be, state->krb_service_name,
+                              state->kdc_srv, PORT_NOT_WORKING);
         nextreq = sdap_kinit_next_kdc(req);
         if (!nextreq) {
             tevent_req_error(req, ENOMEM);
@@ -975,7 +976,8 @@ static void sdap_kinit_done(struct tevent_req *subreq)
         return;
     } else {
         if (kerr == KRB5_KDC_UNREACH) {
-            be_fo_set_port_status(state->be, state->kdc_srv, PORT_NOT_WORKING);
+            be_fo_set_port_status(state->be, state->krb_service_name,
+                                  state->kdc_srv, PORT_NOT_WORKING);
             nextreq = sdap_kinit_next_kdc(req);
             if (!nextreq) {
                 tevent_req_error(req, ENOMEM);
@@ -1306,7 +1308,8 @@ static void sdap_cli_connect_done(struct tevent_req *subreq)
     talloc_zfree(subreq);
     if (ret) {
         /* retry another server */
-        be_fo_set_port_status(state->be, state->srv, PORT_NOT_WORKING);
+        be_fo_set_port_status(state->be, state->service->name,
+                              state->srv, PORT_NOT_WORKING);
         ret = sdap_cli_resolve_next(req);
         if (ret != EOK) {
             tevent_req_error(req, ret);
@@ -1379,7 +1382,8 @@ static void sdap_cli_rootdse_done(struct tevent_req *subreq)
     talloc_zfree(subreq);
     if (ret) {
         if (ret == ETIMEDOUT) { /* retry another server */
-            be_fo_set_port_status(state->be, state->srv, PORT_NOT_WORKING);
+            be_fo_set_port_status(state->be, state->service->name,
+                                  state->srv, PORT_NOT_WORKING);
             ret = sdap_cli_resolve_next(req);
             if (ret != EOK) {
                 tevent_req_error(req, ret);
@@ -1612,7 +1616,8 @@ static void sdap_cli_rootdse_auth_done(struct tevent_req *subreq)
         if (ret == ETIMEDOUT) {
             /* The server we authenticated against went down. Retry another
              * one */
-            be_fo_set_port_status(state->be, state->srv, PORT_NOT_WORKING);
+            be_fo_set_port_status(state->be, state->service->name,
+                                  state->srv, PORT_NOT_WORKING);
             ret = sdap_cli_resolve_next(req);
             if (ret != EOK) {
                 tevent_req_error(req, ret);
@@ -1660,7 +1665,8 @@ int sdap_cli_connect_recv(struct tevent_req *req,
     if (tevent_req_is_error(req, &tstate, &err)) {
         /* mark the server as bad if connection failed */
         if (state->srv) {
-            be_fo_set_port_status(state->be, state->srv, PORT_NOT_WORKING);
+            be_fo_set_port_status(state->be, state->service->name,
+                                  state->srv, PORT_NOT_WORKING);
         } else {
             if (can_retry) {
                 *can_retry = false;
@@ -1672,7 +1678,8 @@ int sdap_cli_connect_recv(struct tevent_req *req,
         }
         return EIO;
     } else if (state->srv) {
-        be_fo_set_port_status(state->be, state->srv, PORT_WORKING);
+        be_fo_set_port_status(state->be, state->service->name,
+                              state->srv, PORT_WORKING);
     }
 
     if (gsh) {
