@@ -2010,9 +2010,8 @@ struct tevent_req *rfc2307bis_nested_groups_send(
     if ((num_groups == 0) ||
         (nesting > dp_opt_get_int(opts->basic, SDAP_NESTING_LEVEL))) {
         /* No parent groups to process or too deep*/
-        tevent_req_done(req);
-        tevent_req_post(req, ev);
-        return req;
+        ret = EOK;
+        goto done;
     }
 
     state->ev = ev;
@@ -2046,7 +2045,18 @@ struct tevent_req *rfc2307bis_nested_groups_send(
         goto done;
     }
 
-    ret = rfc2307bis_nested_groups_step(req);
+    while (state->group_iter < state->num_groups) {
+        ret = rfc2307bis_nested_groups_step(req);
+        if (ret == EOK) {
+            /* This group had already been looked up. Continue to
+             * another group in the same level
+             */
+            state->group_iter++;
+            continue;
+        } else {
+            goto done;
+        }
+    }
 
 done:
     if (ret == EOK) {
