@@ -86,6 +86,7 @@ struct resp_ctx {
     struct be_conn *be_conns;
 
     struct sss_domain_info *domains;
+    int client_idle_timeout;
     struct sysdb_ctx_list *db_list;
 
     struct sss_cmd_table *sss_cmds;
@@ -125,6 +126,8 @@ struct cli_ctx {
     int netgrent_cur;
 
     char *automntmap_name;
+
+    struct tevent_timer *idle;
 };
 
 struct sss_cmd_table {
