@@ -49,6 +49,19 @@
 #include <pthread.h>
 #endif
 
+/*
+* Note we set MSG_NOSIGNAL to avoid
+* having to fiddle with signal masks
+* but also do not want to die in case
+* SIGPIPE gets raised and the application
+* does not handle it.
+*/
+#ifdef MSG_NOSIGNAL
+#define SSS_DEFAULT_WRITE_FLAGS MSG_NOSIGNAL
+#else
+#define SSS_DEFAULT_WRITE_FLAGS 0
+#endif
+
 /* common functions */
 
 int sss_cli_sd = -1; /* the sss client socket descriptor */
@@ -133,14 +146,16 @@ static enum sss_status sss_cli_send_req(enum sss_cli_command cmd,
 
         errno = 0;
         if (datasent < SSS_NSS_HEADER_SIZE) {
-            res = write(sss_cli_sd,
-                        (char *)header + datasent,
-                        SSS_NSS_HEADER_SIZE - datasent);
+            res = send(sss_cli_sd,
+                       (char *)header + datasent,
+                       SSS_NSS_HEADER_SIZE - datasent,
+                       SSS_DEFAULT_WRITE_FLAGS);
         } else {
             rdsent = datasent - SSS_NSS_HEADER_SIZE;
-            res = write(sss_cli_sd,
-                        (const char *)rd->data + rdsent,
-                        rd->len - rdsent);
+            res = send(sss_cli_sd,
+                       (const char *)rd->data + rdsent,
+                       rd->len - rdsent,
+                       SSS_DEFAULT_WRITE_FLAGS);
         }
         error = errno;
 
@@ -154,7 +169,7 @@ static enum sss_status sss_cli_send_req(enum sss_cli_command cmd,
 
             /* Write failed */
             sss_cli_close_socket();
-            *errnop = errno;
+            *errnop = error;
             return SSS_STATUS_UNAVAIL;
         }
 
@@ -264,7 +279,7 @@ static enum sss_status sss_cli_recv_rep(enum sss_cli_command cmd,
              * through. */
 
             sss_cli_close_socket();
-            *errnop = errno;
+            *errnop = error;
             ret = SSS_STATUS_UNAVAIL;
             goto failed;
         }
@@ -928,24 +943,108 @@ errno_t sss_strnlen(const char *str, size_t maxlen, size_t *len)
 }
 
 #if HAVE_PTHREAD
-static pthread_mutex_t sss_nss_mutex = PTHREAD_MUTEX_INITIALIZER;
-static pthread_mutex_t sss_pam_mutex = PTHREAD_MUTEX_INITIALIZER;
+typedef void (*sss_mutex_init)(void);
 
+struct sss_mutex {
+    pthread_mutex_t mtx;
+
+    pthread_once_t once;
+    sss_mutex_init init;
+};
+
+static void sss_nss_mt_init(void);
+static void sss_pam_mt_init(void);
+
+static struct sss_mutex sss_nss_mtx = { .mtx  = PTHREAD_MUTEX_INITIALIZER,
+                                        .once = PTHREAD_ONCE_INIT,
+                                        .init = sss_nss_mt_init };
+
+static struct sss_mutex sss_pam_mtx = { .mtx  = PTHREAD_MUTEX_INITIALIZER,
+                                        .once = PTHREAD_ONCE_INIT,
+                                        .init = sss_pam_mt_init };
+
+
+/* Wrappers for robust mutex support */
+static int sss_mutexattr_setrobust (pthread_mutexattr_t *attr)
+{
+#ifdef HAVE_PTHREAD_MUTEXATTR_SETROBUST
+    return pthread_mutexattr_setrobust(attr, PTHREAD_MUTEX_ROBUST);
+#elif  HAVE_PTHREAD_MUTEXATTR_SETROBUST_NP
+    return pthread_mutexattr_setrobust_np(attr, PTHREAD_MUTEX_ROBUST_NP);
+#else
+#warning Robust mutexes are not supported on this platform.
+    return 0;
+#endif
+}
+
+static int sss_mutex_consistent(pthread_mutex_t *mtx)
+{
+#ifdef HAVE_PTHREAD_MUTEX_CONSISTENT
+    return pthread_mutex_consistent(mtx);
+#elif HAVE_PTHREAD_MUTEX_CONSISTENT_NP
+    return pthread_mutex_consistent_np(mtx);
+#else
+#warning Robust mutexes are not supported on this platform.
+    return 0;
+#endif
+}
+
+/* Generic mutex init, lock, unlock functions */
+static void sss_mt_init(struct sss_mutex *m)
+{
+    pthread_mutexattr_t attr;
+
+    if (pthread_mutexattr_init(&attr) != 0) {
+        return;
+    }
+    if (sss_mutexattr_setrobust(&attr) != 0) {
+        return;
+    }
+
+    pthread_mutex_init(&m->mtx, &attr);
+    pthread_mutexattr_destroy(&attr);
+}
+
+static void sss_mt_lock(struct sss_mutex *m)
+{
+    pthread_once(&m->once, m->init);
+    if (pthread_mutex_lock(&m->mtx) == EOWNERDEAD) {
+        sss_cli_close_socket();
+        sss_mutex_consistent(&m->mtx);
+    }
+}
+
+static void sss_mt_unlock(struct sss_mutex *m)
+{
+    pthread_mutex_unlock(&m->mtx);
+}
+
+/* NSS mutex wrappers */
+static void sss_nss_mt_init(void)
+{
+    sss_mt_init(&sss_nss_mtx);
+}
 void sss_nss_lock(void)
 {
-    pthread_mutex_lock(&sss_nss_mutex);
+    sss_mt_lock(&sss_nss_mtx);
 }
 void sss_nss_unlock(void)
 {
-    pthread_mutex_unlock(&sss_nss_mutex);
+    sss_mt_unlock(&sss_nss_mtx);
+}
+
+/* NSS mutex wrappers */
+static void sss_pam_mt_init(void)
+{
+    sss_mt_init(&sss_pam_mtx);
 }
 void sss_pam_lock(void)
 {
-    pthread_mutex_lock(&sss_pam_mutex);
+    sss_mt_lock(&sss_pam_mtx);
 }
 void sss_pam_unlock(void)
 {
-    pthread_mutex_unlock(&sss_pam_mutex);
+    sss_mt_unlock(&sss_pam_mtx);
 }
 
 #else
