@@ -29,14 +29,30 @@
 #include <pwd.h>
 #include <grp.h>
 #include <string.h>
+#include <stdint.h>
+#include <limits.h>
 
 #ifndef HAVE_ERRNO_T
 #define HAVE_ERRNO_T
 typedef int errno_t;
 #endif
 
+
+#ifndef EOK
+#define EOK 0
+#endif
+
 #define SSS_NSS_PROTOCOL_VERSION 1
 #define SSS_PAM_PROTOCOL_VERSION 3
+#define SSS_SUDO_PROTOCOL_VERSION 0
+#define SSS_AUTOFS_PROTOCOL_VERSION 1
+#define SSS_SSH_PROTOCOL_VERSION 0
+
+#ifdef LOGIN_NAME_MAX
+#define SSS_NAME_MAX LOGIN_NAME_MAX
+#else
+#define SSS_NAME_MAX 256
+#endif
 
 /**
  * @defgroup sss_cli_command SSS client commands
@@ -125,6 +141,7 @@ enum sss_cli_command {
     SSS_NSS_SETRPCENT      = 0x0093,
     SSS_NSS_GETRPCENT      = 0x0094,
     SSS_NSS_ENDRPCENT      = 0x0095,
+#endif
 
 /* services */
 
@@ -134,6 +151,7 @@ enum sss_cli_command {
     SSS_NSS_GETSERVENT     = 0x00A4,
     SSS_NSS_ENDSERVENT     = 0x00A5,
 
+#if 0
 /* shadow */
 
     SSS_NSS_GETSPNAM       = 0x00B1,
@@ -143,6 +161,20 @@ enum sss_cli_command {
     SSS_NSS_ENDSPENT       = 0x00B5,
 #endif
 
+/* SUDO */
+    SSS_SUDO_GET_SUDORULES = 0x00C1,
+    SSS_SUDO_GET_DEFAULTS  = 0x00C2,
+
+/* autofs */
+    SSS_AUTOFS_SETAUTOMNTENT    = 0x00D1,
+    SSS_AUTOFS_GETAUTOMNTENT    = 0x00D2,
+    SSS_AUTOFS_GETAUTOMNTBYNAME  = 0x00D3,
+    SSS_AUTOFS_ENDAUTOMNTENT    = 0x00D4,
+
+/* SSH */
+    SSS_SSH_GET_USER_PUBKEYS = 0x00E1,
+    SSS_SSH_GET_HOST_PUBKEYS = 0x00E2,
+
 /* PAM related calls */
     SSS_PAM_AUTHENTICATE     = 0x00F1, /**< see pam_sm_authenticate(3) for
                                         * details.
@@ -331,6 +363,10 @@ enum response_type {
                           * the user.This should only be used in the case where
                           * it is not possile to use SSS_PAM_USER_INFO.
                           * @param A zero terminated string. */
+    SSS_PAM_SELINUX_MAP, /**< A content of a SELinux user mapping file. This
+                          * file should be then written to a particular
+                          * subdir in /etc/selinux for pam_selinux to read
+                          * @param A zero terminated string. */
 };
 
 /**
@@ -445,6 +481,21 @@ int sss_pam_make_request(enum sss_cli_command cmd,
                                      uint8_t **repbuf, size_t *replen,
                                      int *errnop);
 
+int sss_sudo_make_request(enum sss_cli_command cmd,
+                          struct sss_cli_req_data *rd,
+                          uint8_t **repbuf, size_t *replen,
+                          int *errnop);
+
+int sss_autofs_make_request(enum sss_cli_command cmd,
+                            struct sss_cli_req_data *rd,
+                            uint8_t **repbuf, size_t *replen,
+                            int *errnop);
+
+int sss_ssh_make_request(enum sss_cli_command cmd,
+                         struct sss_cli_req_data *rd,
+                         uint8_t **repbuf, size_t *replen,
+                         int *errnop);
+
 #ifndef SAFEALIGN_COPY_UINT32
 static inline void
 safealign_memcpy(void *dest, const void *src, size_t n, size_t *counter)
@@ -455,11 +506,29 @@ safealign_memcpy(void *dest, const void *src, size_t n, size_t *counter)
     }
 }
 
+#define SAFEALIGN_SET_VALUE(dest, value, type, pctr) do { \
+    type CV_MACRO_val = (type)(value); \
+    safealign_memcpy(dest, &CV_MACRO_val, sizeof(type), pctr); \
+} while(0)
+
+#ifndef SAFEALIGN_SET_UINT32
+#define SAFEALIGN_SET_UINT32(dest, value, pctr) \
+    SAFEALIGN_SET_VALUE(dest, value, uint32_t, pctr)
+#endif
+
 #define SAFEALIGN_COPY_UINT32(dest, src, pctr) \
     safealign_memcpy(dest, src, sizeof(uint32_t), pctr)
 #endif
 
-#endif /* _SSSCLI_H */
+#ifndef SAFEALIGN_SET_UINT16
+#define SAFEALIGN_SET_UINT16(dest, value, pctr) \
+    SAFEALIGN_SET_VALUE(dest, value, uint16_t, pctr)
+#endif
+
+#ifndef SAFEALIGN_COPY_UINT16
+#define SAFEALIGN_COPY_UINT16(dest, src, pctr) \
+    safealign_memcpy(dest, src, sizeof(uint16_t), pctr)
+#endif
 
 #if 0
 
@@ -493,3 +562,12 @@ void sss_nss_lock(void);
 void sss_nss_unlock(void);
 void sss_pam_lock(void);
 void sss_pam_unlock(void);
+
+errno_t sss_readrep_copy_string(const char *in,
+                                size_t *offset,
+                                size_t *slen,
+                                size_t *dlen,
+                                char **out,
+                                size_t *size);
+
+#endif /* _SSSCLI_H */
