@@ -195,7 +195,7 @@ static void do_failed_login_test(uint32_t failed_login_attempts,
                           (long long) last_failed_login);
     fail_unless(ret == EOK, "ldb_msg_add_string failed");
 
-    ret = check_failed_login_attempts(test_ctx, test_ctx->confdb, ldb_msg,
+    ret = check_failed_login_attempts(test_ctx->confdb, ldb_msg,
                                       &returned_failed_login_attempts,
                                       &delayed_until);
     fail_unless(ret == expected_result,
@@ -308,6 +308,9 @@ int main(int argc, const char *argv[])
         POPT_TABLEEND
     };
 
+    /* Set debug level to invalid value so we can deside if -d 0 was used. */
+    debug_level = SSSDBG_INVALID;
+
     pc = poptGetContext(argv[0], argc, argv, long_options, 0);
     while((opt = poptGetNextOpt(pc)) != -1) {
         switch(opt) {
@@ -320,6 +323,8 @@ int main(int argc, const char *argv[])
     }
     poptFreeContext(pc);
 
+    CONVERT_AND_SET_DEBUG_LEVEL(debug_level);
+
     tests_set_cwd();
 
     ret = clean_db_dir();
