@@ -77,6 +77,9 @@ END_TEST
 START_TEST(test_check_num_opts)
 {
     fail_if(IPA_OPTS_BASIC_TEST != SDAP_OPTS_BASIC);
+    fail_if(IPA_OPTS_SVC_TEST != SDAP_OPTS_SERVICES);
+    fail_if(IPA_OPTS_AUTOMNTMAP_TEST != SDAP_OPTS_AUTOFS_MAP);
+    fail_if(IPA_OPTS_AUTOMNTENTRY_TEST != SDAP_OPTS_AUTOFS_ENTRY);
     fail_if(IPA_KRB5_OPTS_TEST != KRB5_OPTS);
 }
 END_TEST
