@@ -26,6 +26,8 @@
 #include <talloc.h>
 #include <check.h>
 #include "util/util.h"
+#include "util/sss_utf8.h"
+#include "util/murmurhash3.h"
 #include "tests/common.h"
 
 START_TEST(test_parse_args)
@@ -312,6 +314,137 @@ START_TEST(test_size_t_overflow)
 }
 END_TEST
 
+START_TEST(test_utf8_lowercase)
+{
+    const uint8_t munchen_utf8_upcase[] = { 'M', 0xC3, 0x9C, 'N', 'C', 'H', 'E', 'N', 0x0 };
+    const uint8_t munchen_utf8_lowcase[] = { 'm', 0xC3, 0xBC, 'n', 'c', 'h', 'e', 'n', 0x0 };
+    uint8_t *lcase;
+    size_t nlen;
+
+    lcase = sss_utf8_tolower(munchen_utf8_upcase,
+                             strlen((const char *)munchen_utf8_upcase),
+                             &nlen);
+    fail_if(strlen((const char *) munchen_utf8_upcase) != nlen); /* This is not true for utf8 strings in general */
+    fail_if(memcmp(lcase, munchen_utf8_lowcase, nlen));
+    sss_utf8_free(lcase);
+}
+END_TEST
+
+START_TEST(test_utf8_talloc_lowercase)
+{
+    const uint8_t munchen_utf8_upcase[] = { 'M', 0xC3, 0x9C, 'N', 'C', 'H', 'E', 'N', 0x0 };
+    const uint8_t munchen_utf8_lowcase[] = { 'm', 0xC3, 0xBC, 'n', 'c', 'h', 'e', 'n', 0x0 };
+    uint8_t *lcase;
+    size_t nsize;
+
+    TALLOC_CTX *test_ctx;
+    test_ctx = talloc_new(NULL);
+    fail_if(test_ctx == NULL);
+
+    lcase = sss_tc_utf8_tolower(test_ctx, munchen_utf8_upcase,
+                                strlen((const char *) munchen_utf8_upcase),
+                                &nsize);
+    fail_if(memcmp(lcase, munchen_utf8_lowcase, nsize));
+    talloc_free(test_ctx);
+}
+END_TEST
+
+START_TEST(test_utf8_talloc_str_lowercase)
+{
+    const uint8_t munchen_utf8_upcase[] = { 'M', 0xC3, 0x9C, 'N', 'C', 'H', 'E', 'N', 0x0 };
+    const uint8_t munchen_utf8_lowcase[] = { 'm', 0xC3, 0xBC, 'n', 'c', 'h', 'e', 'n', 0x0 };
+    char *lcase;
+
+    TALLOC_CTX *test_ctx;
+    test_ctx = talloc_new(NULL);
+    fail_if(test_ctx == NULL);
+
+    lcase = sss_tc_utf8_str_tolower(test_ctx, (const char *) munchen_utf8_upcase);
+    fail_if(memcmp(lcase, munchen_utf8_lowcase, strlen(lcase)));
+    talloc_free(test_ctx);
+}
+END_TEST
+
+START_TEST(test_utf8_caseeq)
+{
+    const uint8_t munchen_utf8_upcase[] = { 'M', 0xC3, 0x9C, 'N', 'C', 'H', 'E', 'N', 0x0 };
+    const uint8_t munchen_utf8_lowcase[] = { 'm', 0xC3, 0xBC, 'n', 'c', 'h', 'e', 'n', 0x0 };
+    const uint8_t czech_utf8_lowcase[] = { 0xC4, 0x8D, 'e', 'c', 'h', 0x0 };
+    const uint8_t czech_utf8_upcase[] = { 0xC4, 0x8C, 'e', 'c', 'h', 0x0 };
+    const uint8_t czech_utf8_lowcase_neg[] = { 0xC4, 0x8E, 'e', 'c', 'h', 0x0 };
+    errno_t ret;
+
+    ret = sss_utf8_case_eq(munchen_utf8_upcase, munchen_utf8_lowcase);
+    fail_unless(ret == EOK, "Latin 1 Supplement comparison failed\n");
+
+    ret = sss_utf8_case_eq(czech_utf8_upcase, czech_utf8_lowcase);
+    fail_unless(ret == EOK, "Latin Extended A comparison failed\n");
+
+    ret = sss_utf8_case_eq(czech_utf8_upcase, czech_utf8_lowcase_neg);
+    fail_if(ret == EOK, "Negative test succeeded\n");
+}
+END_TEST
+
+START_TEST(test_utf8_check)
+{
+    const char *invalid = "ad\351la\357d";
+    const uint8_t valid[] = { 'M', 0xC3, 0x9C, 'N', 'C', 'H', 'E', 'N', 0x0 };
+    bool ret;
+
+    ret = sss_utf8_check(valid, strlen((const char *) valid));
+    fail_unless(ret == true, "Positive test failed\n");
+
+    ret = sss_utf8_check((const uint8_t *) invalid, strlen(invalid));
+    fail_unless(ret == false, "Negative test succeeded\n");
+}
+END_TEST
+
+START_TEST(test_murmurhash3_check)
+{
+    const char *tests[6] = { "1052800007", "1052800008", "1052800000",
+                             "abcdefghijk", "abcdefghili", "abcdefgh000" };
+    uint32_t results[6];
+    int i, j;
+
+    for (i = 0; i< 6; i++) {
+        results[i] = murmurhash3(tests[i],
+                                 strlen(tests[i]),
+                                 0xdeadbeef);
+        for (j = 0; j < i; j++) {
+            fail_if(results[i] == results[j]);
+        }
+    }
+}
+END_TEST
+
+START_TEST(test_murmurhash3_random)
+{
+    char test[16];
+    uint32_t result1;
+    uint32_t result2;
+    unsigned int init_seed;
+    unsigned int seed;
+    size_t len;
+    int i;
+
+    /* generate a random string so each time we test with different values */
+    init_seed = time(0);
+    seed = init_seed;
+    /* use also random length (min len = 1) */
+    len = 1 + rand_r(&seed) % 14;
+    for (i = 0; i < len; i++) {
+        test[i] = 1 + rand_r(&seed) % 254;
+    }
+    test[len] = '\0'; /* null terminate */
+
+    fprintf(stdout, "test_murmurhash3_random seed: %d\n", init_seed);
+
+    result1 = murmurhash3(test, len + 1, init_seed);
+    result2 = murmurhash3(test, len + 1, init_seed);
+    fail_if(result1 != result2);
+}
+END_TEST
+
 Suite *util_suite(void)
 {
     Suite *s = suite_create("util");
@@ -324,7 +457,23 @@ Suite *util_suite(void)
     tcase_add_test (tc_util, test_parse_args);
     tcase_set_timeout(tc_util, 60);
 
+    TCase *tc_utf8 = tcase_create("utf8");
+    tcase_add_test (tc_utf8, test_utf8_lowercase);
+    tcase_add_test (tc_utf8, test_utf8_talloc_lowercase);
+    tcase_add_test (tc_utf8, test_utf8_talloc_str_lowercase);
+    tcase_add_test (tc_utf8, test_utf8_caseeq);
+    tcase_add_test (tc_utf8, test_utf8_check);
+
+    tcase_set_timeout(tc_utf8, 60);
+
+    TCase *tc_mh3 = tcase_create("murmurhash3");
+    tcase_add_test (tc_mh3, test_murmurhash3_check);
+    tcase_add_test (tc_mh3, test_murmurhash3_random);
+    tcase_set_timeout(tc_mh3, 60);
+
     suite_add_tcase (s, tc_util);
+    suite_add_tcase (s, tc_utf8);
+    suite_add_tcase (s, tc_mh3);
 
     return s;
 }
@@ -343,6 +492,9 @@ int main(int argc, const char *argv[])
         POPT_TABLEEND
     };
 
+    /* Set debug level to invalid value so we can deside if -d 0 was used. */
+    debug_level = SSSDBG_INVALID;
+
     pc = poptGetContext(argv[0], argc, argv, long_options, 0);
     while((opt = poptGetNextOpt(pc)) != -1) {
         switch(opt) {
@@ -355,6 +507,8 @@ int main(int argc, const char *argv[])
     }
     poptFreeContext(pc);
 
+    CONVERT_AND_SET_DEBUG_LEVEL(debug_level);
+
     tests_set_cwd();
 
     srunner_run_all(sr, CK_ENV);
