@@ -32,7 +32,7 @@
 int main(int argc, const char **argv)
 {
     int ret = EXIT_SUCCESS;
-    int pc_debug = 0;
+    int pc_debug = SSSDBG_DEFAULT;
     const char *pc_groupname = NULL;
     struct tools_ctx *tctx = NULL;
 
@@ -61,7 +61,7 @@ int main(int argc, const char **argv)
         BAD_POPT_PARAMS(pc, poptStrerror(ret), ret, fini);
     }
 
-    debug_level = pc_debug;
+    debug_level = debug_convert_old_level(pc_debug);
 
     pc_groupname = poptGetArg(pc);
     if (pc_groupname == NULL) {
@@ -90,9 +90,7 @@ int main(int argc, const char **argv)
         goto fini;
     }
 
-    ret = sysdb_getgrnam_sync(tctx, tctx->sysdb,
-                              tctx->octx->name, tctx->local,
-                              tctx->octx);
+    ret = sysdb_getgrnam_sync(tctx, tctx->sysdb, tctx->octx->name, tctx->octx);
     if (ret != EOK) {
         /* Error message will be printed in the switch */
         goto done;
