@@ -40,7 +40,7 @@ int main(int argc, const char **argv)
     char *pc_gecos = NULL;
     char *pc_home = NULL;
     char *pc_shell = NULL;
-    int pc_debug = 0;
+    int pc_debug = SSSDBG_DEFAULT;
     const char *pc_selinux_user = NULL;
     struct poptOption long_options[] = {
         POPT_AUTOHELP
@@ -109,7 +109,7 @@ int main(int argc, const char **argv)
         BAD_POPT_PARAMS(pc, poptStrerror(ret), ret, fini);
     }
 
-    debug_level = pc_debug;
+    debug_level = debug_convert_old_level(pc_debug);
 
     /* username is an argument without --option */
     pc_username = poptGetArg(pc);
@@ -139,9 +139,7 @@ int main(int argc, const char **argv)
         goto fini;
     }
     /* check the username to be able to give sensible error message */
-    ret = sysdb_getpwnam_sync(tctx, tctx->sysdb,
-                              tctx->octx->name, tctx->local,
-                              tctx->octx);
+    ret = sysdb_getpwnam_sync(tctx, tctx->sysdb, tctx->octx->name, tctx->octx);
     if (ret != EOK) {
         ERROR("Cannot find user in local domain, "
               "modifying users is allowed only in local domain\n");
