@@ -94,15 +94,17 @@ static errno_t get_uid_from_pid(const pid_t pid, uid_t *uid)
         if (error == ENOENT) {
             DEBUG(7, ("Proc file [%s] is not available anymore, continuing.\n",
                       path));
-            return EOK;
+            error = EOK;
+            goto fail_fd;
         }
         DEBUG(1, ("fstat failed [%d][%s].\n", error, strerror(error)));
-        return error;
+        goto fail_fd;
     }
 
     if (!S_ISREG(stat_buf.st_mode)) {
         DEBUG(1, ("not a regular file\n"));
-        return EINVAL;
+        error = EINVAL;
+        goto fail_fd;
     }
 
     while ((ret = read(fd, buf, BUFSIZE)) != 0) {
@@ -112,10 +114,13 @@ static errno_t get_uid_from_pid(const pid_t pid, uid_t *uid)
                 continue;
             }
             DEBUG(1, ("read failed [%d][%s].\n", error, strerror(error)));
-            return error;
+            goto fail_fd;
         }
     }
 
+    /* Guarantee NULL-termination in case we read the full BUFSIZE somehow */
+    buf[BUFSIZE-1] = '\0';
+
     ret = close(fd);
     if (ret == -1) {
         error = errno;
@@ -132,7 +137,7 @@ static errno_t get_uid_from_pid(const pid_t pid, uid_t *uid)
         } else {
             *e = '\0';
         }
-        num = strtouint32(p, &endptr, 10);
+        num = (uint32_t) strtoint32(p, &endptr, 10);
         error = errno;
         if (error != 0) {
             DEBUG(1, ("strtol failed [%s].\n", strerror(error)));
@@ -143,11 +148,6 @@ static errno_t get_uid_from_pid(const pid_t pid, uid_t *uid)
             return EINVAL;
         }
 
-        if (num >= UINT32_MAX) {
-            DEBUG(1, ("uid out of range.\n"));
-            return ERANGE;
-        }
-
     } else {
         DEBUG(1, ("format error\n"));
         return EINVAL;
@@ -156,6 +156,10 @@ static errno_t get_uid_from_pid(const pid_t pid, uid_t *uid)
     *uid = num;
 
     return EOK;
+
+fail_fd:
+    close(fd);
+    return error;
 }
 
 static errno_t name_to_pid(const char *name, pid_t *pid)
